@@ -20,7 +20,7 @@ def image_to_tensor(image: Image) -> np.ndarray:
         Preprocessed numpy array.
     """
     image = image.convert('RGB')
-    tensor = np.asarray(image)
+    tensor = np.asarray(image, dtype=np.float16)
     tensor = crop_and_resize(tensor, 331)
     tensor = (tensor / 255.0 - 0.5) * 2.0
     assert tensor.shape == (331, 331, 3)
