@@ -1,6 +1,7 @@
 """Init for utils."""
 from .graph_utils import load_graph, pb_to_tensorboard_event, freeze_session, freeze_graph_from_ckpt, wrap_frozen_graph
-from .tf_runner import TFRunner, TFRunnerOld
+from .graph_utils import freeze_keras_model
+from .tf_runner import TFRunner
 from .runner import Runner
 
 __all__ = [
@@ -12,7 +13,7 @@ __all__ = [
     'freeze_graph_from_ckpt',
     'wrap_frozen_graph',
     'TFRunner',
-    'TFRunnerOld',
+    'freeze_keras_model'
 ]
 
 try:
