@@ -3,6 +3,9 @@ import os
 from typing import List
 import tensorflow as tf
 import tensorflow.compat.v1 as tf_v1
+from tensorflow.python.framework import dtypes
+from tensorflow.python.framework.convert_to_constants import convert_variables_to_constants_v2
+from tensorflow.python.tools import optimize_for_inference_lib
 from tensorflow.python.platform import gfile
 
 
@@ -178,3 +181,35 @@ def wrap_frozen_graph(graph_def: tf_v1.GraphDef, inputs: List[str], outputs: Lis
     return wrapped_import.prune(
         tf.nest.map_structure(import_graph.as_graph_element, inputs),
         tf.nest.map_structure(import_graph.as_graph_element, outputs))
+
+
+def optimize_frozen_graph_def(frozen_graph_def, input_node_names: List[str], output_node_names: List[str]):
+    """Remove trainable parameters from graph_def."""
+    output_graph_def = optimize_for_inference_lib.optimize_for_inference(
+        frozen_graph_def,
+        input_node_names=input_node_names,
+        output_node_names=output_node_names,
+        placeholder_type_enum=dtypes.float32.as_datatype_enum)
+    # Remove Const nodes.
+    for i in reversed(range(len(output_graph_def.node))):
+        if output_graph_def.node[i].op == 'Const':
+            del output_graph_def.node[i]
+        for attr in ['T', 'Tshape', 'N', 'Tidx', 'Tdim',
+                     'use_cudnn_on_gpu', 'Index', 'Tperm', 'is_training',
+                     'Tpaddings']:
+            if attr in output_graph_def.node[i].attr:
+                del output_graph_def.node[i].attr[attr]
+    return output_graph_def
+
+
+def freeze_keras_model(model, save_dir: str) -> None:
+    """Freeze keras model and export it to protobuf file."""
+    full_model = tf.function(lambda x: model(x))
+    full_model = full_model.get_concrete_function(
+        tf.TensorSpec(model.inputs[0].shape, model.inputs[0].dtype, name=model.input_names[0]))
+    frozen_func = convert_variables_to_constants_v2(full_model)
+    graph_def = frozen_func.graph.as_graph_def()
+    tf.io.write_graph(graph_or_graph_def=graph_def,
+                      logdir=save_dir,
+                      name=f"{model.name}.pb",
+                      as_text=False)
